==> loadmychunks-1.2.0%2B1.19.2%2Bfabric-sources.jar: CCTRegistryContent.java <==
//? if computercraft {
/*package com.drathonix.loadmychunks.common.integ.cct;

import com.drathonix.loadmychunks.common.integ.cct.turtle.TurtleChunkLoader;
import com.drathonix.loadmychunks.common.integ.cct.turtle.TurtleChunkLoaderUpgrade;
import com.drathonix.loadmychunks.common.integ.cct.turtle.UpgradeModeller;
import com.drathonix.loadmychunks.common.registry.LoaderType;
import com.drathonix.loadmychunks.common.registry.LoaderTypeKeys;
import com.drathonix.loadmychunks.common.registry.custom.LoaderTypeRegistry;
import dan200.computercraft.api.turtle.ITurtleUpgrade;
//? if >=1.20.6
import dan200.computercraft.api.upgrades.UpgradeType;
//? if >1.16.5
import dev.architectury.registry.registries.RegistrySupplier;

//? if >1.16.5 && <1.20.4
/^import dan200.computercraft.api.turtle.TurtleUpgradeSerialiser;^/
//? if >1.16.5 && <1.20.6
/^import dan200.computercraft.api.upgrades.UpgradeSerialiser;^/

//? if <=1.16.5 {
/^import me.shedaniel.architectury.registry.RegistrySupplier;
^///?}

//? if >=1.19.2 {
import dan200.computercraft.client.turtle.TurtleUpgradeModellers;
//?}

import java.util.*;

public class CCTRegistryContent {
    //? if >=1.20.6 {
    public static List<RegistrySupplier<UpgradeType<? extends TurtleChunkLoaderUpgrade>>> registrySuppliers = new ArrayList<>();
    //?} else if <1.20.6 && >1.20.1 {
    /^public static List<RegistrySupplier<UpgradeSerialiser<? extends ITurtleUpgrade>>> registrySuppliers = new ArrayList<>();
    ^///?} else if <=1.20.1 && >1.16.5 {
    /^public static List<RegistrySupplier<TurtleUpgradeSerialiser<? extends ITurtleUpgrade>>> registrySuppliers = new ArrayList<>();
    ^///?} else {
    /^public static List<RegistrySupplier<ITurtleUpgrade>> registrySuppliers = new ArrayList<>();
    ^///?}

    public static void registerClient() {
        //? if >1.18.2 {
        registrySuppliers.forEach(v->{
            TurtleUpgradeModellers.register(v.get(), new UpgradeModeller<>());
        });
        //?}
    }

    public static void register(){
        LoaderTypeRegistry.register(LoaderTypeKeys.CCT_TURTLE_LOADER, new LoaderType<>(TurtleChunkLoader::new));
    }
}
*///?}

==> loadmychunks-1.2.1%2B1.18.2%2Bfabric-sources.jar: CCTRegistryContent.java <==
//? if computercraft {
/*package com.drathonix.loadmychunks.common.integ.cct;

import com.drathonix.loadmychunks.common.integ.cct.turtle.TurtleChunkLoader;
import com.drathonix.loadmychunks.common.integ.cct.turtle.TurtleChunkLoaderUpgrade;
import com.drathonix.loadmychunks.common.integ.cct.turtle.UpgradeModeller;
import com.drathonix.loadmychunks.common.registry.LoaderType;
import com.drathonix.loadmychunks.common.registry.LoaderTypeKeys;
import com.drathonix.loadmychunks.common.registry.custom.LoaderTypeRegistry;
import dan200.computercraft.api.turtle.ITurtleUpgrade;
//? if >=1.20.6
/^import dan200.computercraft.api.upgrades.UpgradeType;^/
//? if >1.16.5
import dev.architectury.registry.registries.RegistrySupplier;

//? if >1.16.5 && <1.20.4
import dan200.computercraft.api.turtle.TurtleUpgradeSerialiser;
//? if >1.16.5 && <1.20.6
import dan200.computercraft.api.upgrades.UpgradeSerialiser;

//? if <=1.16.5 {
/^import me.shedaniel.architectury.registry.RegistrySupplier;
^///?}

//? if >=1.19.2 {
/^import dan200.computercraft.client.turtle.TurtleUpgradeModellers;
^///?}

import java.util.*;

public class CCTRegistryContent {
    //? if >=1.20.6 {
    /^public static List<RegistrySupplier<UpgradeType<? extends TurtleChunkLoaderUpgrade>>> registrySuppliers = new ArrayList<>();
    ^///?} else if <1.20.6 && >1.20.1 {
    /^public static List<RegistrySupplier<UpgradeSerialiser<? extends ITurtleUpgrade>>> registrySuppliers = new ArrayList<>();
    ^///?} else if <=1.20.1 && >1.16.5 {
    public static List<RegistrySupplier<TurtleUpgradeSerialiser<? extends ITurtleUpgrade>>> registrySuppliers = new ArrayList<>();
    //?} else {
    /^public static List<RegistrySupplier<ITurtleUpgrade>> registrySuppliers = new ArrayList<>();
    ^///?}

    public static void registerClient() {
        //? if >1.18.2 {
        /^registrySuppliers.forEach(v->{
            TurtleUpgradeModellers.register(v.get(), new UpgradeModeller<>());
        });
        ^///?}
    }

    public static void register(){
        LoaderTypeRegistry.register(LoaderTypeKeys.CCT_TURTLE_LOADER, new LoaderType<>(TurtleChunkLoader::new));
    }
}
*///?}
